/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ekTb8JhU);
  numBytes += sLine_init(&sLine_WzOBj5FS);
  numBytes += sLine_init(&sLine_Q0gW20hb);
  numBytes += sLine_init(&sLine_VUF7fzhS);
  numBytes += sLine_init(&sLine_9TO1OVeJ);
  numBytes += sBiquad_init(&sBiquad_s_DHRwoLZV);
  numBytes += sLine_init(&sLine_jewEz75O);
  numBytes += sLine_init(&sLine_viQs0mTx);
  numBytes += sLine_init(&sLine_XsfNRv1b);
  numBytes += sLine_init(&sLine_z6sT43il);
  numBytes += sBiquad_init(&sBiquad_s_vBLI6Xfk);
  numBytes += sLine_init(&sLine_VfxwYiKS);
  numBytes += sLine_init(&sLine_g25x8lrH);
  numBytes += sLine_init(&sLine_kNvhcgNC);
  numBytes += sLine_init(&sLine_UqALfCV9);
  numBytes += sLine_init(&sLine_ugMK8VuI);
  numBytes += sBiquad_init(&sBiquad_s_vxYlpOKR);
  numBytes += sLine_init(&sLine_N3izDh66);
  numBytes += sLine_init(&sLine_FBA0UhNW);
  numBytes += sLine_init(&sLine_7aBKiUoj);
  numBytes += sLine_init(&sLine_f37iE9tS);
  numBytes += sLine_init(&sLine_pVvWkTtN);
  numBytes += sBiquad_init(&sBiquad_s_CdSNsmgR);
  numBytes += sLine_init(&sLine_ScFWU1q4);
  numBytes += sLine_init(&sLine_yAcevV8s);
  numBytes += sLine_init(&sLine_hit30lnj);
  numBytes += sLine_init(&sLine_eVqcG9Ta);
  numBytes += sBiquad_init(&sBiquad_s_n16HtM5L);
  numBytes += sLine_init(&sLine_7lAoKRgz);
  numBytes += sLine_init(&sLine_GJpXT7ko);
  numBytes += sLine_init(&sLine_QYHOuEDN);
  numBytes += sLine_init(&sLine_jnrOj0Cq);
  numBytes += sLine_init(&sLine_YCOqUTuy);
  numBytes += sBiquad_init(&sBiquad_s_s6T2OepG);
  numBytes += sLine_init(&sLine_L6dfXcxj);
  numBytes += sPhasor_k_init(&sPhasor_gu23g1lV, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_stGfxQ4t);
  numBytes += sRPole_init(&sRPole_hn1883kz);
  numBytes += sRPole_init(&sRPole_I3SA3a3g);
  numBytes += sTabhead_init(&sTabhead_VE2ZVPYJ, &hTable_QUyZYC5c);
  numBytes += sTabread_init(&sTabread_6dZd6sx3, &hTable_QUyZYC5c, false);
  numBytes += sTabread_init(&sTabread_xneFoeiA, &hTable_QUyZYC5c, false);
  numBytes += sLine_init(&sLine_bH09qJsC);
  numBytes += sTabhead_init(&sTabhead_ts9nihXP, &hTable_zFSS8M7r);
  numBytes += sTabread_init(&sTabread_mVGqJLoX, &hTable_zFSS8M7r, false);
  numBytes += sTabread_init(&sTabread_PyPIvteG, &hTable_zFSS8M7r, false);
  numBytes += sLine_init(&sLine_RPb8Cf7s);
  numBytes += sTabwrite_init(&sTabwrite_EYbVue7d, &hTable_zFSS8M7r);
  numBytes += sTabwrite_init(&sTabwrite_Xkd38uaD, &hTable_QUyZYC5c);
  numBytes += sLine_init(&sLine_uSFrZKT9);
  numBytes += sPhasor_k_init(&sPhasor_xQiOGI05, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_yfi0YNnZ);
  numBytes += sRPole_init(&sRPole_gqQzXJaS);
  numBytes += sRPole_init(&sRPole_4U11Kbcx);
  numBytes += sTabhead_init(&sTabhead_AruzvT1e, &hTable_XY0fzTTU);
  numBytes += sTabread_init(&sTabread_As9qGLPi, &hTable_XY0fzTTU, false);
  numBytes += sTabread_init(&sTabread_iwEASf7o, &hTable_XY0fzTTU, false);
  numBytes += sLine_init(&sLine_Bfn7scDq);
  numBytes += sTabhead_init(&sTabhead_cn7xYak3, &hTable_QeCXKJhw);
  numBytes += sTabread_init(&sTabread_Si7YCTOd, &hTable_QeCXKJhw, false);
  numBytes += sTabread_init(&sTabread_j6XLy77r, &hTable_QeCXKJhw, false);
  numBytes += sLine_init(&sLine_5P3i24DQ);
  numBytes += sTabwrite_init(&sTabwrite_eDOZXxAF, &hTable_QeCXKJhw);
  numBytes += sTabwrite_init(&sTabwrite_obeV3vmO, &hTable_XY0fzTTU);
  numBytes += sLine_init(&sLine_rFFazbjn);
  numBytes += sPhasor_k_init(&sPhasor_8b7OxT56, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_mwd7mao0);
  numBytes += sRPole_init(&sRPole_HVLtdsOl);
  numBytes += sRPole_init(&sRPole_WUmwWC6u);
  numBytes += sTabhead_init(&sTabhead_PiyZM6el, &hTable_74GBMlFw);
  numBytes += sTabread_init(&sTabread_KHCzTO32, &hTable_74GBMlFw, false);
  numBytes += sTabread_init(&sTabread_TSgXNNc0, &hTable_74GBMlFw, false);
  numBytes += sLine_init(&sLine_ODVCT8sL);
  numBytes += sTabhead_init(&sTabhead_YDRdo39U, &hTable_JRvGoMPY);
  numBytes += sTabread_init(&sTabread_h3Led779, &hTable_JRvGoMPY, false);
  numBytes += sTabread_init(&sTabread_TPV4cke9, &hTable_JRvGoMPY, false);
  numBytes += sLine_init(&sLine_zeC4tKMb);
  numBytes += sTabwrite_init(&sTabwrite_omFF6cTp, &hTable_JRvGoMPY);
  numBytes += sTabwrite_init(&sTabwrite_i9fMCQ4B, &hTable_74GBMlFw);
  numBytes += cVar_init_f(&cVar_32wA7G8C, 0.0f);
  numBytes += cVar_init_f(&cVar_jBSCX0qC, 0.0f);
  numBytes += cVar_init_f(&cVar_7Bbv6kAy, 0.0f);
  numBytes += cVar_init_f(&cVar_RDDm14Lm, 0.0f);
  numBytes += cSlice_init(&cSlice_SS1ACZJv, 1, -1);
  numBytes += cVar_init_f(&cVar_evP30tgl, 1337.0f);
  numBytes += cVar_init_f(&cVar_n5QcNEOL, 0.0f);
  numBytes += cIf_init(&cIf_C8sBuGX6, false);
  numBytes += cIf_init(&cIf_aGLcRz5o, false);
  numBytes += cBinop_init(&cBinop_7mwhD3jT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_rZ9Nfw2L, false);
  numBytes += cBinop_init(&cBinop_2Q31GMdj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZR4R5uJn, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_cbOKIbPj, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_dIA18ndK, 0.0f);
  numBytes += cIf_init(&cIf_AmL2T60i, false);
  numBytes += cIf_init(&cIf_eCTiWwYj, false);
  numBytes += cBinop_init(&cBinop_MEVC7V5m, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QGHz4OTu, false);
  numBytes += cBinop_init(&cBinop_mEhsTx1G, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WW5PHVR9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_WtnH9F0Z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hy8PALgj, 0.0f);
  numBytes += cIf_init(&cIf_JFLWxa63, false);
  numBytes += cIf_init(&cIf_dinlY5ug, false);
  numBytes += cBinop_init(&cBinop_ec2PQrnk, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xFv5NpJU, false);
  numBytes += cBinop_init(&cBinop_XseXtZak, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1L8ifPjz, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Vho0YBSq, -15.0f); // __eq
  numBytes += cIf_init(&cIf_PjhWFElL, false);
  numBytes += cSlice_init(&cSlice_B17MNlo7, 1, -1);
  numBytes += cVar_init_f(&cVar_0gGZL8wC, 0.0f);
  numBytes += cSlice_init(&cSlice_XYunYLcs, 1, -1);
  numBytes += cVar_init_f(&cVar_QAEaWR7k, 0.0f);
  numBytes += cSlice_init(&cSlice_0yy9XTnH, 1, -1);
  numBytes += cVar_init_f(&cVar_4OMuVNpY, 0.0f);
  numBytes += cSlice_init(&cSlice_ckP14BvF, 1, -1);
  numBytes += cVar_init_f(&cVar_P602dJ5j, 0.313f);
  numBytes += cBinop_init(&cBinop_7z5sOrmX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Se8CaPJb, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tT3uwaps, 0.0f);
  numBytes += cVar_init_f(&cVar_X3k8MUn2, 1337.0f);
  numBytes += cVar_init_f(&cVar_hQupw7hW, 0.3f);
  numBytes += cBinop_init(&cBinop_9GAhEYU8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MftVZGv0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2oct8axn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Bi64pO8m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zbOoq601, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VOqN0BGN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pCmHXWud, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_p0iuxIM4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_oYqLcZsa, 0.0f);
  numBytes += cVar_init_f(&cVar_PMjCi0E6, 1337.0f);
  numBytes += cVar_init_f(&cVar_E38kpyHE, 0.313f);
  numBytes += cBinop_init(&cBinop_KmN1IyN1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bfLumqpK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NDrx3VWX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JfphSHk4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CfcQNgiM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BtMsUm3L, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_TNWrKY33, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3zminUvd, 0.0f);
  numBytes += cVar_init_f(&cVar_mH5gY6D0, 1037.0f);
  numBytes += cVar_init_f(&cVar_97hLXvsR, 0.4f);
  numBytes += cBinop_init(&cBinop_RgBL9bOa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OQyZZiO6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ADhLIk3y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jgfJ7Aap, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uLe1kri8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LNfwtYHD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_PAszra08, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KmYDJbjQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jvRgxtTs, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_w0I0spd1, 1, -1);
  numBytes += cVar_init_f(&cVar_2cYhzwba, 1337.0f);
  numBytes += cVar_init_f(&cVar_P5tOjSoW, 0.0f);
  numBytes += cIf_init(&cIf_p5Drmr3t, false);
  numBytes += cIf_init(&cIf_tlcgznqR, false);
  numBytes += cBinop_init(&cBinop_vpXnaNF3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VcMYRBU4, false);
  numBytes += cBinop_init(&cBinop_4tYANaBQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_j7AGvLJf, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9SkGbMfd, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KWRX6wej, 0.0f);
  numBytes += cIf_init(&cIf_l1tRjqDl, false);
  numBytes += cIf_init(&cIf_Dg4VHJqg, false);
  numBytes += cBinop_init(&cBinop_SdPnBVBO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_sfnJ52ai, false);
  numBytes += cBinop_init(&cBinop_RDq2dpog, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_pBdiPj5G, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_qe1gs5yu, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_NlecnWKm, 0.0f);
  numBytes += cIf_init(&cIf_JOhdLeJq, false);
  numBytes += cIf_init(&cIf_bs8b63EJ, false);
  numBytes += cBinop_init(&cBinop_vwRatdA9, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pM8Pta84, false);
  numBytes += cBinop_init(&cBinop_Yvr1nFy2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_d1sVIpnR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_KFqXM780, -15.0f); // __eq
  numBytes += cIf_init(&cIf_73Fvhk4z, false);
  numBytes += cSlice_init(&cSlice_g9RLPGP9, 1, -1);
  numBytes += cVar_init_f(&cVar_CAKLTTrG, 0.0f);
  numBytes += cSlice_init(&cSlice_6jchruG3, 1, -1);
  numBytes += cVar_init_f(&cVar_rPHnOPvO, 0.0f);
  numBytes += cSlice_init(&cSlice_zWgwpn6M, 1, -1);
  numBytes += cVar_init_f(&cVar_zP8Uk1bt, 0.0f);
  numBytes += cSlice_init(&cSlice_9uN4p2tH, 1, -1);
  numBytes += cVar_init_f(&cVar_dES19fuW, 0.313f);
  numBytes += cBinop_init(&cBinop_fkBQKe59, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cm5GbFTA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tctckCyL, 0.0f);
  numBytes += cVar_init_f(&cVar_GCMy22i8, 1337.0f);
  numBytes += cVar_init_f(&cVar_kRb6lUIq, 0.3f);
  numBytes += cBinop_init(&cBinop_pPFHmUx6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2WZckWUP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TV29g51k, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n5AFFLYs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FqF2dX3K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IpZS6mLp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cWFoABdM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MSCazSt5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_f8djp4gO, 0.0f);
  numBytes += cVar_init_f(&cVar_yukE54co, 1337.0f);
  numBytes += cVar_init_f(&cVar_JqXdK6Bg, 0.313f);
  numBytes += cBinop_init(&cBinop_jqQG5gaZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WwTbg1YO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5IPhFjFd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OdLUSDxW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GUUrbipj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_POHbDqxP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GnvCuyVu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IviAANdG, 0.0f);
  numBytes += cVar_init_f(&cVar_ejoO4Si4, 1037.0f);
  numBytes += cVar_init_f(&cVar_TNOWVyyP, 0.4f);
  numBytes += cBinop_init(&cBinop_nhDaBjqm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0AcGl8h8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LZsmSx84, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8Z555QEa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NXpL7RAR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wM2YMp34, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QKVzhCAM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3wxkYUbD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y4rbOhb5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_f17j4Qme, 5705.6f);
  numBytes += cVar_init_f(&cVar_hrpfoaSD, 313.3f);
  numBytes += cBinop_init(&cBinop_YnSGspsC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_OgtgyK7a, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_tdJ9Q1AI, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_r0TI1wHb, 0.0f);
  numBytes += cVar_init_f(&cVar_QKuHPLjb, 0.0f);
  numBytes += cVar_init_f(&cVar_M7istRv3, 0.0f);
  numBytes += cVar_init_f(&cVar_t9hNfcIQ, 0.0f);
  numBytes += cVar_init_f(&cVar_0MnmqKTP, 0.0f);
  numBytes += cVar_init_f(&cVar_k7q8YUdt, 0.0f);
  numBytes += cVar_init_f(&cVar_xawyCRKd, 0.0f);
  numBytes += cVar_init_f(&cVar_ytXYLyff, 0.0f);
  numBytes += cVar_init_f(&cVar_nqkTUzU0, 0.0f);
  numBytes += cVar_init_f(&cVar_t1Nj9i9S, 0.0f);
  numBytes += cVar_init_f(&cVar_BFlq6i32, 0.0f);
  numBytes += cVar_init_f(&cVar_zkZqGFiD, 0.0f);
  numBytes += cVar_init_s(&cVar_f2RBrPzc, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_MmgYKiTO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_usSTnGav, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A0OdtnvF, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_qNDRt4DT, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_zaE3L2gr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_faBSrxzN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j25z59Nz, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_cTYX5IdP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_GLY8d7YN, 0.0f);
  numBytes += hTable_init(&hTable_zFSS8M7r, 256);
  numBytes += cDelay_init(this, &cDelay_xxY8nZWJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BMNeiRBv, 0.0f);
  numBytes += hTable_init(&hTable_QUyZYC5c, 256);
  numBytes += cVar_init_f(&cVar_lnaQdjP6, 14.0f);
  numBytes += cBinop_init(&cBinop_ARyvrQpR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6VB28Jrz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gb3ppdit, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hScgjD4d, 14.0f);
  numBytes += cBinop_init(&cBinop_stvsCfbf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nv2yY4WC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_okxRsif4, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_0pKNBuRQ, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_MMnz7oyU, 1, -1);
  numBytes += cVar_init_f(&cVar_HnUiwS0x, 0.2f);
  numBytes += cSlice_init(&cSlice_qnlGptfV, 1, -1);
  numBytes += cVar_init_f(&cVar_DftVKNXS, 0.0f);
  numBytes += cSlice_init(&cSlice_cZ0l2fnf, 1, -1);
  numBytes += cVar_init_f(&cVar_9xCkxOmd, 2.0f);
  numBytes += cSlice_init(&cSlice_jMI2OXgR, 1, -1);
  numBytes += cVar_init_f(&cVar_kYB40tmG, 0.5f);
  numBytes += cVar_init_s(&cVar_2TrH8XTc, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_9SPDjo4A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E2D7hDSg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_guVfMHe6, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_koYQNZig, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_D5n6QwL7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nNmz4r3m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rrdX9lu4, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Tl4bCYBz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_YmVEoCr4, 0.0f);
  numBytes += hTable_init(&hTable_QeCXKJhw, 256);
  numBytes += cDelay_init(this, &cDelay_TLcIpOaV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y5S2ihQB, 0.0f);
  numBytes += hTable_init(&hTable_XY0fzTTU, 256);
  numBytes += cVar_init_f(&cVar_8u1AqJ0t, 14.0f);
  numBytes += cBinop_init(&cBinop_UnuVloBB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LwOVWhra, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HlMysWMX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vPYkbbKr, 14.0f);
  numBytes += cBinop_init(&cBinop_z9UtfEvy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HG9PX9aW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lTcbdWRK, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_cj82k0EH, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_vQjoaHCs, 1, -1);
  numBytes += cVar_init_f(&cVar_gbwWbLJT, 0.2f);
  numBytes += cSlice_init(&cSlice_70QRgWqO, 1, -1);
  numBytes += cVar_init_f(&cVar_i9OCorJF, 0.0f);
  numBytes += cSlice_init(&cSlice_O9MsYH41, 1, -1);
  numBytes += cVar_init_f(&cVar_wHqFQ6un, 2.0f);
  numBytes += cSlice_init(&cSlice_7VUPDsh2, 1, -1);
  numBytes += cVar_init_f(&cVar_AsQfpLk8, 0.5f);
  numBytes += cVar_init_s(&cVar_sgfVk7Nw, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_w1qjihjn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eh06IYON, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mpp4hzrt, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Y136Y0ia, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_uweqV1Go, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DTwTlh99, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C09TBsEn, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_lyHd4ICk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nnE1sZ6C, 0.0f);
  numBytes += hTable_init(&hTable_JRvGoMPY, 256);
  numBytes += cDelay_init(this, &cDelay_Y09XCAYX, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XtyeifGo, 0.0f);
  numBytes += hTable_init(&hTable_74GBMlFw, 256);
  numBytes += cVar_init_f(&cVar_tVSBClxV, 14.0f);
  numBytes += cBinop_init(&cBinop_5tO0lypO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_UG6HMhnf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cS7BY53p, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_G1b8be9t, 14.0f);
  numBytes += cBinop_init(&cBinop_CVLCMWzI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_BFaA2E5L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_STsFoYTL, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_L5mFo2Sd, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_w5tDkXIW, 1, -1);
  numBytes += cVar_init_f(&cVar_V2hqCCuW, 0.2f);
  numBytes += cSlice_init(&cSlice_1uOmlfJd, 1, -1);
  numBytes += cVar_init_f(&cVar_fgcS2GyX, 0.0f);
  numBytes += cSlice_init(&cSlice_RCQYIfxw, 1, -1);
  numBytes += cVar_init_f(&cVar_SIEin6FD, 2.0f);
  numBytes += cSlice_init(&cSlice_jGa9vrjs, 1, -1);
  numBytes += cVar_init_f(&cVar_w53ho9nW, 0.5f);
  numBytes += sVarf_init(&sVarf_YukM7lya, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dDRR30Fg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1VzumjFX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tuHrmjp4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jEZfElsJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7X6sbdCJ, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_zFSS8M7r);
  hTable_free(&hTable_QUyZYC5c);
  hTable_free(&hTable_QeCXKJhw);
  hTable_free(&hTable_XY0fzTTU);
  hTable_free(&hTable_JRvGoMPY);
  hTable_free(&hTable_74GBMlFw);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_zFSS8M7r; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_QUyZYC5c; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_QeCXKJhw; // del-1397-flanger-r
    case 0x578173CB: return &hTable_XY0fzTTU; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_JRvGoMPY; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_74GBMlFw; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ng9n8zRm_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NLCM5LGY_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rn4RZHeZ_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MGATtlAG_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LRRw0LQ2_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1YiusPGP_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qEaIIXlZ_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hfBm1Fqj_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2RYBvNPj_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JXrrPlWp_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_spz3ybVu_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nbD1vylN_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zwo1yKPx_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ID9gI2k0_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3mFZs1ZD_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OqZHE7AL_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rQpDtB6R_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dT9pRnhz_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5ZbZmUYU_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4LUCthbw_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qR6yfns4_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GLppN1sJ_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qQoC8itl_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7fi8ZTgZ_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DPEyCJjb_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XEwEiSEp_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5a0dnoPg_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wjlF9XQE_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C63HJeUF_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XfjYQiW3_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H7xCgM0u_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MJwsksKV_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WCLKm6N1_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bOJYoEDA_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qkINjJTc_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2ru8sHG8_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_29SIIQGF_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DcfDeHzy_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vkOgxuZx_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YuNwMWF1_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QiIOXlzY_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9TQVfR2o_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zv4Bqwsy_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ocyzREFL_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RNBsXfGq_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cKCKqSY8_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fIVDDeq5_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EhRHNDR2_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JWydOYXc_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFSAIt1I_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OMucdLQc_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fEIBkvFv_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XakEBqSd_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yv06xjEX_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KVyhLDIQ_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AXWgcvlu_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PivsYGAp_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_32wA7G8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IliKlp3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jBSCX0qC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9wlIIHf3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7Bbv6kAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AtEqdjiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_RDDm14Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pJGVpTSO_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NVkBS9h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eo9lBYCM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jvAVD9jG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_qF0xMBgO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SS1ACZJv, 0, m, &cSlice_SS1ACZJv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JzTKMZFV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SS1ACZJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_I0eU7o3e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_I0eU7o3e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_evP30tgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I0eU7o3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_I0eU7o3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5ZbZmUYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_n5QcNEOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nJSKX3OW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_C8sBuGX6, 0, m, &cIf_C8sBuGX6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_C8sBuGX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BXsuBYqp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_aGLcRz5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HJUAWKbz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xqfR5Gsv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_wz69v1pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mwhD3jT, HV_BINOP_POW, 0, m, &cBinop_7mwhD3jT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7mwhD3jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZ9Nfw2L, 0, m, &cIf_rZ9Nfw2L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g980TThs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Y4mxBwJ7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rl1jviFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGLcRz5o, 0, m, &cIf_aGLcRz5o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8B1VLNfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8d9l8YFs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8d9l8YFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGLcRz5o, 1, m, &cIf_aGLcRz5o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xqfR5Gsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_g980TThs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HJUAWKbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rZ9Nfw2L, 0, m, &cIf_rZ9Nfw2L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y4mxBwJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mwhD3jT, HV_BINOP_POW, 1, m, &cBinop_7mwhD3jT_sendMessage);
  cMsg_wz69v1pt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_rZ9Nfw2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_PAszra08, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_nJSKX3OW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C8sBuGX6, 1, m, &cIf_C8sBuGX6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BXsuBYqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZR4R5uJn, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZR4R5uJn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbOKIbPj, HV_BINOP_EQ, 1, m, &cBinop_cbOKIbPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EZn00wyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Q31GMdj, HV_BINOP_ADD, 0, m, &cBinop_2Q31GMdj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Q31GMdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8B1VLNfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rl1jviFS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZR4R5uJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZ9Nfw2L, 1, m, &cIf_rZ9Nfw2L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cbOKIbPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UvBOSAui_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UvBOSAui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PAszra08, m);
}

void Heavy_WSTD_FL3NGR::cCast_zqWVYJIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Q31GMdj, HV_BINOP_ADD, 1, m, &cBinop_2Q31GMdj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZR4R5uJn, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZR4R5uJn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbOKIbPj, HV_BINOP_EQ, 0, m, &cBinop_cbOKIbPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BBVxzBEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n5QcNEOL, 0, m, &cVar_n5QcNEOL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_03yFhOB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EZn00wyd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_dIA18ndK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Suex24Kx_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AmL2T60i, 0, m, &cIf_AmL2T60i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_AmL2T60i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lofGC549_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_eCTiWwYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DfYmATPj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_utTKszds_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_dQGBPF9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEVC7V5m, HV_BINOP_POW, 0, m, &cBinop_MEVC7V5m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MEVC7V5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGHz4OTu, 0, m, &cIf_QGHz4OTu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1sZwMcBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oShQjuYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rcBAzbkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eCTiWwYj, 0, m, &cIf_eCTiWwYj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IyV5XfZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K0qbTf6h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_K0qbTf6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eCTiWwYj, 1, m, &cIf_eCTiWwYj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_utTKszds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1sZwMcBj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DfYmATPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QGHz4OTu, 0, m, &cIf_QGHz4OTu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oShQjuYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEVC7V5m, HV_BINOP_POW, 1, m, &cBinop_MEVC7V5m_sendMessage);
  cMsg_dQGBPF9B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_QGHz4OTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_N4Ex4SHB_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82pzd4q1_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YPZPyHsP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Suex24Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AmL2T60i, 1, m, &cIf_AmL2T60i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lofGC549_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WW5PHVR9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WW5PHVR9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtnH9F0Z, HV_BINOP_EQ, 1, m, &cBinop_WtnH9F0Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_no0eQJRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEhsTx1G, HV_BINOP_ADD, 0, m, &cBinop_mEhsTx1G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mEhsTx1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IyV5XfZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rcBAzbkk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WW5PHVR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGHz4OTu, 1, m, &cIf_QGHz4OTu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WtnH9F0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MIo4dxrU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MIo4dxrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_N4Ex4SHB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82pzd4q1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YPZPyHsP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X22biFRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEhsTx1G, HV_BINOP_ADD, 1, m, &cBinop_mEhsTx1G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WW5PHVR9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WW5PHVR9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtnH9F0Z, HV_BINOP_EQ, 0, m, &cBinop_WtnH9F0Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rMf3j5QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dIA18ndK, 0, m, &cVar_dIA18ndK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BmCvINmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_no0eQJRN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_hy8PALgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ecys5wTo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JFLWxa63, 0, m, &cIf_JFLWxa63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_JFLWxa63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_l5KbzDeE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_dinlY5ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hHQScoSd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_91yNtu4C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_hDgX2Sfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ec2PQrnk, HV_BINOP_POW, 0, m, &cBinop_ec2PQrnk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ec2PQrnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFv5NpJU, 0, m, &cIf_xFv5NpJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uXiHaEbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vDfsx6zw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BYmT6u2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dinlY5ug, 0, m, &cIf_dinlY5ug_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IyO2ykPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iuJqWZz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iuJqWZz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dinlY5ug, 1, m, &cIf_dinlY5ug_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_91yNtu4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uXiHaEbD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hHQScoSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xFv5NpJU, 0, m, &cIf_xFv5NpJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vDfsx6zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ec2PQrnk, HV_BINOP_POW, 1, m, &cBinop_ec2PQrnk_sendMessage);
  cMsg_hDgX2Sfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_xFv5NpJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jvRgxtTs, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Ecys5wTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JFLWxa63, 1, m, &cIf_JFLWxa63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l5KbzDeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1L8ifPjz, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1L8ifPjz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vho0YBSq, HV_BINOP_EQ, 1, m, &cBinop_Vho0YBSq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_crmhie9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XseXtZak, HV_BINOP_ADD, 0, m, &cBinop_XseXtZak_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XseXtZak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IyO2ykPJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BYmT6u2E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1L8ifPjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFv5NpJU, 1, m, &cIf_xFv5NpJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Vho0YBSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tfr8XGqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Tfr8XGqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jvRgxtTs, m);
}

void Heavy_WSTD_FL3NGR::cCast_AZXgnyrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XseXtZak, HV_BINOP_ADD, 1, m, &cBinop_XseXtZak_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1L8ifPjz, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1L8ifPjz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vho0YBSq, HV_BINOP_EQ, 0, m, &cBinop_Vho0YBSq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OEelAoHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hy8PALgj, 0, m, &cVar_hy8PALgj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bll1733G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_crmhie9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_PjhWFElL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_KmYDJbjQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RUPUv5hD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B17MNlo7, 0, m, &cSlice_B17MNlo7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VzaNaCf8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_B17MNlo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_23VCC8ro_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_23VCC8ro_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0gGZL8wC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_23VCC8ro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_23VCC8ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rQpDtB6R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VzaNaCf8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XYunYLcs, 0, m, &cSlice_XYunYLcs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qF0xMBgO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_XYunYLcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_b1utigHB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_b1utigHB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_QAEaWR7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b1utigHB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_b1utigHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qR6yfns4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JzTKMZFV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0yy9XTnH, 0, m, &cSlice_0yy9XTnH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_txrurO7T_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_0yy9XTnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mc89ZTkH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mc89ZTkH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_4OMuVNpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mc89ZTkH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mc89ZTkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dT9pRnhz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_txrurO7T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ckP14BvF, 0, m, &cSlice_ckP14BvF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ckP14BvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Emq1eOYB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Emq1eOYB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_P602dJ5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Emq1eOYB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Emq1eOYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4LUCthbw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PHwZdwEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ekTb8JhU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GpRcMk4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WzOBj5FS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_a5IjG3vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q0gW20hb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1pLWhL4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VUF7fzhS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QQdNwREq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9TO1OVeJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qnxa71Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VrVZU7FS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_VrVZU7FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7z5sOrmX, HV_BINOP_DIVIDE, 1, m, &cBinop_7z5sOrmX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_besNf0zG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_iKZJc5f9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_YUJdAOKA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NbyPJsz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_iKZJc5f9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YUJdAOKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7z5sOrmX, HV_BINOP_DIVIDE, 0, m, &cBinop_7z5sOrmX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_besNf0zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NbyPJsz5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7z5sOrmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Se8CaPJb, HV_BINOP_MULTIPLY, 1, m, &cBinop_Se8CaPJb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Se8CaPJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rIBDfXD4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cawWj0At_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_S6X3Z9K0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eSnkJ2Be_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_aDOQ0U5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sWC7sN5p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OOtwKMaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mVs4IVDi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mVs4IVDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Se8CaPJb, HV_BINOP_MULTIPLY, 0, m, &cBinop_Se8CaPJb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vsWeLPfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_f0BBkomB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f0BBkomB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqvmig7D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_S3x3L0si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tT3uwaps, 1, m, &cVar_tT3uwaps_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_tT3uwaps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zIgY1hcJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ce0E39tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MftVZGv0, HV_BINOP_MULTIPLY, 1, m, &cBinop_MftVZGv0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VxMxsyD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ce0E39tf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yc6PbvY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NHj03AeS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NHj03AeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2oct8axn, HV_BINOP_MULTIPLY, 1, m, &cBinop_2oct8axn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QMfv08Iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bi64pO8m, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bi64pO8m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ufTkXAzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QMfv08Iv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HzVuwDyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbOoq601, HV_BINOP_MULTIPLY, 1, m, &cBinop_zbOoq601_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_L9TBPslw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VvQR3RrM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VvQR3RrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VOqN0BGN, HV_BINOP_MULTIPLY, 1, m, &cBinop_VOqN0BGN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_X3k8MUn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7nPwkN9D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OOtwKMaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8pObtook_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hQupw7hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vsWeLPfI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cawWj0At_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_aDOQ0U5x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rIBDfXD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_S6X3Z9K0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_eSnkJ2Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7fi8ZTgZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_sWC7sN5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qQoC8itl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mYBz09w5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GLppN1sJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cqvmig7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3cwP1oAH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3cwP1oAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GAhEYU8, HV_BINOP_MULTIPLY, 1, m, &cBinop_9GAhEYU8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9GAhEYU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fTCziQ6b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fTCziQ6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mYBz09w5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zIgY1hcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_baS6bwJc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_baS6bwJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T4puI0MF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pA4NC6Np_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b336KsNM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HVbKeeji_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r8yWYOsm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OZPil1Mi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MftVZGv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PHwZdwEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2oct8axn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GpRcMk4i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Bi64pO8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a5IjG3vB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zbOoq601_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1pLWhL4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VOqN0BGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QQdNwREq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_u5e1DWQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X3k8MUn2, 0, m, &cVar_X3k8MUn2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ztrOYO0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hQupw7hW, 1, m, &cVar_hQupw7hW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OZPil1Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MftVZGv0, HV_BINOP_MULTIPLY, 0, m, &cBinop_MftVZGv0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b336KsNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbOoq601, HV_BINOP_MULTIPLY, 0, m, &cBinop_zbOoq601_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r8yWYOsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2oct8axn, HV_BINOP_MULTIPLY, 0, m, &cBinop_2oct8axn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pA4NC6Np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VOqN0BGN, HV_BINOP_MULTIPLY, 0, m, &cBinop_VOqN0BGN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HVbKeeji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bi64pO8m, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bi64pO8m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T4puI0MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_7nPwkN9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hQupw7hW, 0, m, &cVar_hQupw7hW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8pObtook_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tT3uwaps, 0, m, &cVar_tT3uwaps_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HOkSHLBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jewEz75O, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EYRHMgNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_viQs0mTx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1AqFhDSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XsfNRv1b, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eq4btygM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z6sT43il, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Gne81bWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lSsiSSHl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lSsiSSHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCmHXWud, HV_BINOP_DIVIDE, 1, m, &cBinop_pCmHXWud_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lQIVIMcG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QwOCYoib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JuAEpPZM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QfOoBYYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_QwOCYoib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JuAEpPZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCmHXWud, HV_BINOP_DIVIDE, 0, m, &cBinop_pCmHXWud_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lQIVIMcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QfOoBYYz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pCmHXWud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0iuxIM4, HV_BINOP_MULTIPLY, 1, m, &cBinop_p0iuxIM4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p0iuxIM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wGrJJrKA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LzmEDAGN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_JrflNhXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lu3rj5QI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_0klvbo2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CIGzpQe7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Jt4rJWxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_rafZ1Wxp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rafZ1Wxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0iuxIM4, HV_BINOP_MULTIPLY, 0, m, &cBinop_p0iuxIM4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VuvNyIPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Xq0dJdLK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Xq0dJdLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WrOdxBhX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Vquik7Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NDrx3VWX, HV_BINOP_MULTIPLY, 1, m, &cBinop_NDrx3VWX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MkXya4XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oYqLcZsa, 1, m, &cVar_oYqLcZsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KsZCc6uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JfphSHk4, HV_BINOP_MULTIPLY, 1, m, &cBinop_JfphSHk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DRv2kEU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Y7RsRgVm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y7RsRgVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CfcQNgiM, HV_BINOP_MULTIPLY, 1, m, &cBinop_CfcQNgiM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_oYqLcZsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RMbSD14i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_PMjCi0E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ico6x1n6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Jt4rJWxz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LpCnLrc5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_E38kpyHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VuvNyIPs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wGrJJrKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_JrflNhXc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LzmEDAGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0klvbo2F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_lu3rj5QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5a0dnoPg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CIGzpQe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XEwEiSEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3Sakkx19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DPEyCJjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WrOdxBhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RB9wEYfz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RB9wEYfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmN1IyN1, HV_BINOP_MULTIPLY, 1, m, &cBinop_KmN1IyN1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KmN1IyN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q72VgTCO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q72VgTCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Sakkx19_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RMbSD14i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7fvcXFlo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7fvcXFlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7v1wFXtP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1DJJC58h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Udr5jR7t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uE76XnUI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bfLumqpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HOkSHLBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NDrx3VWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EYRHMgNU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JfphSHk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1AqFhDSB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CfcQNgiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eq4btygM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_DWX9meF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E38kpyHE, 1, m, &cVar_E38kpyHE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Dk57SR0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PMjCi0E6, 0, m, &cVar_PMjCi0E6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LpCnLrc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oYqLcZsa, 0, m, &cVar_oYqLcZsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ico6x1n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E38kpyHE, 0, m, &cVar_E38kpyHE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uE76XnUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bfLumqpK, HV_BINOP_MULTIPLY, 0, m, &cBinop_bfLumqpK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7v1wFXtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CfcQNgiM, HV_BINOP_MULTIPLY, 0, m, &cBinop_CfcQNgiM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Udr5jR7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NDrx3VWX, HV_BINOP_MULTIPLY, 0, m, &cBinop_NDrx3VWX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1DJJC58h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JfphSHk4, HV_BINOP_MULTIPLY, 0, m, &cBinop_JfphSHk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rzxIvdHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VfxwYiKS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_gsf8N4gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g25x8lrH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RXYDsIlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kNvhcgNC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cPoh8rD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqALfCV9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4lMCQv3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ugMK8VuI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_e58kmsKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oOVitnvU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_oOVitnvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtMsUm3L, HV_BINOP_DIVIDE, 1, m, &cBinop_BtMsUm3L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ce3XZaYx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_OI5ozGy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QxMSxTox_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2NcfyRz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OI5ozGy7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QxMSxTox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtMsUm3L, HV_BINOP_DIVIDE, 0, m, &cBinop_BtMsUm3L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ce3XZaYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2NcfyRz3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BtMsUm3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TNWrKY33, HV_BINOP_MULTIPLY, 1, m, &cBinop_TNWrKY33_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TNWrKY33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sKm1TXH3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vclKwVD9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_E8k2deRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A8BAGiwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_mCahaCXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P4jlnzXm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oHHecJKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_YU8xsWGQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YU8xsWGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TNWrKY33, HV_BINOP_MULTIPLY, 0, m, &cBinop_TNWrKY33_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dF7Kre7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QRLb1UlS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QRLb1UlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vnBWhrQN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lKyMAl9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQyZZiO6, HV_BINOP_MULTIPLY, 1, m, &cBinop_OQyZZiO6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K8cI8pZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8SaMuVmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8SaMuVmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lKyMAl9o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7luIthzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2svq7NNP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2svq7NNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADhLIk3y, HV_BINOP_MULTIPLY, 1, m, &cBinop_ADhLIk3y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_enHQAnkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgfJ7Aap, HV_BINOP_MULTIPLY, 1, m, &cBinop_jgfJ7Aap_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_j9huh89u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5Gp2b0om_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5Gp2b0om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_enHQAnkW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TAsW0Kjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3zminUvd, 1, m, &cVar_3zminUvd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_20huJM00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uLe1kri8, HV_BINOP_MULTIPLY, 1, m, &cBinop_uLe1kri8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_agBWe9Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u7KyJhSM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u7KyJhSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LNfwtYHD, HV_BINOP_MULTIPLY, 1, m, &cBinop_LNfwtYHD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3zminUvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZDZK0isw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_mH5gY6D0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AldmUIxX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_oHHecJKF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y9BINJ7b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_97hLXvsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dF7Kre7O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vclKwVD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mCahaCXT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sKm1TXH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_E8k2deRY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_A8BAGiwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XfjYQiW3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_P4jlnzXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C63HJeUF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6Ak0O7FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wjlF9XQE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vnBWhrQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YlGocnfc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YlGocnfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RgBL9bOa, HV_BINOP_MULTIPLY, 1, m, &cBinop_RgBL9bOa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RgBL9bOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AEwIn0kJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AEwIn0kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6Ak0O7FW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZDZK0isw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2jU02IGl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2jU02IGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZMHdfaOs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRelDo2x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wG2EJVza_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mQZhSAjf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRHzt2AI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IOWn83HJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OQyZZiO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rzxIvdHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ADhLIk3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gsf8N4gz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jgfJ7Aap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXYDsIlR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uLe1kri8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cPoh8rD6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LNfwtYHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4lMCQv3H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_AwoYOg37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_97hLXvsR, 1, m, &cVar_97hLXvsR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_q9lcKduE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mH5gY6D0, 0, m, &cVar_mH5gY6D0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IOWn83HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQyZZiO6, HV_BINOP_MULTIPLY, 0, m, &cBinop_OQyZZiO6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wG2EJVza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uLe1kri8, HV_BINOP_MULTIPLY, 0, m, &cBinop_uLe1kri8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QRHzt2AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADhLIk3y, HV_BINOP_MULTIPLY, 0, m, &cBinop_ADhLIk3y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QRelDo2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LNfwtYHD, HV_BINOP_MULTIPLY, 0, m, &cBinop_LNfwtYHD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mQZhSAjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgfJ7Aap, HV_BINOP_MULTIPLY, 0, m, &cBinop_jgfJ7Aap_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZMHdfaOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_y9BINJ7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3zminUvd, 0, m, &cVar_3zminUvd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AldmUIxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_97hLXvsR, 0, m, &cVar_97hLXvsR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N4Ex4SHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PjhWFElL, 1, m, &cIf_PjhWFElL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qIAmITuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KmYDJbjQ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_82pzd4q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qIAmITuw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YPZPyHsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PjhWFElL, 0, m, &cIf_PjhWFElL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HC42THMZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w0I0spd1, 0, m, &cSlice_w0I0spd1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oZZGGT4t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_w0I0spd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RqloD5AY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RqloD5AY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_2cYhzwba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RqloD5AY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RqloD5AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WCLKm6N1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_P5tOjSoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3dhvPx4D_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_p5Drmr3t, 0, m, &cIf_p5Drmr3t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_p5Drmr3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yV70A55R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_tlcgznqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_GZhpohBj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_X9aGRkiF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_ts31B2hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vpXnaNF3, HV_BINOP_POW, 0, m, &cBinop_vpXnaNF3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vpXnaNF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VcMYRBU4, 0, m, &cIf_VcMYRBU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lZGdsMqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DXbPNii9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pUl4w3B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tlcgznqR, 0, m, &cIf_tlcgznqR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_N6TO4lqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IXeSHHh1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IXeSHHh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tlcgznqR, 1, m, &cIf_tlcgznqR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X9aGRkiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lZGdsMqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GZhpohBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VcMYRBU4, 0, m, &cIf_VcMYRBU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DXbPNii9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vpXnaNF3, HV_BINOP_POW, 1, m, &cBinop_vpXnaNF3_sendMessage);
  cMsg_ts31B2hy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_VcMYRBU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QKVzhCAM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_3dhvPx4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p5Drmr3t, 1, m, &cIf_p5Drmr3t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yV70A55R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7AGvLJf, HV_BINOP_GREATER_THAN, 1, m, &cBinop_j7AGvLJf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9SkGbMfd, HV_BINOP_EQ, 1, m, &cBinop_9SkGbMfd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Yi0kyjKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4tYANaBQ, HV_BINOP_ADD, 0, m, &cBinop_4tYANaBQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4tYANaBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N6TO4lqv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pUl4w3B4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_j7AGvLJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VcMYRBU4, 1, m, &cIf_VcMYRBU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9SkGbMfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmOSO4Ft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BmOSO4Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QKVzhCAM, m);
}

void Heavy_WSTD_FL3NGR::cCast_lE8Zo8ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yi0kyjKK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_vPsg1H7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4tYANaBQ, HV_BINOP_ADD, 1, m, &cBinop_4tYANaBQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7AGvLJf, HV_BINOP_GREATER_THAN, 0, m, &cBinop_j7AGvLJf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9SkGbMfd, HV_BINOP_EQ, 0, m, &cBinop_9SkGbMfd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_n9IKcOab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P5tOjSoW, 0, m, &cVar_P5tOjSoW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KWRX6wej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3wNDOs16_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_l1tRjqDl, 0, m, &cIf_l1tRjqDl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_l1tRjqDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HK03m9cP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Dg4VHJqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_TENiHXwL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QVOCnory_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_3JVmkmi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdPnBVBO, HV_BINOP_POW, 0, m, &cBinop_SdPnBVBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SdPnBVBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sfnJ52ai, 0, m, &cIf_sfnJ52ai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4wb3JcDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_E9L9K7qH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GGlNvdHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EEUVSdSC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yakLgRD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dg4VHJqg, 0, m, &cIf_Dg4VHJqg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EEUVSdSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dg4VHJqg, 1, m, &cIf_Dg4VHJqg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QVOCnory_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4wb3JcDB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TENiHXwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sfnJ52ai, 0, m, &cIf_sfnJ52ai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E9L9K7qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdPnBVBO, HV_BINOP_POW, 1, m, &cBinop_SdPnBVBO_sendMessage);
  cMsg_3JVmkmi7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_sfnJ52ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kF1RAjoU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d3QKG0zR_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_t5pZc6XR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_3wNDOs16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l1tRjqDl, 1, m, &cIf_l1tRjqDl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HK03m9cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBdiPj5G, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pBdiPj5G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qe1gs5yu, HV_BINOP_EQ, 1, m, &cBinop_qe1gs5yu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HD7UHqEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDq2dpog, HV_BINOP_ADD, 0, m, &cBinop_RDq2dpog_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RDq2dpog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GGlNvdHF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yakLgRD2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pBdiPj5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sfnJ52ai, 1, m, &cIf_sfnJ52ai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qe1gs5yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5EWzIIsW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5EWzIIsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kF1RAjoU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d3QKG0zR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_t5pZc6XR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mvq7jN9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KWRX6wej, 0, m, &cVar_KWRX6wej_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yn1IbxCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HD7UHqEt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_7TZUoaK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDq2dpog, HV_BINOP_ADD, 1, m, &cBinop_RDq2dpog_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBdiPj5G, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pBdiPj5G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qe1gs5yu, HV_BINOP_EQ, 0, m, &cBinop_qe1gs5yu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NlecnWKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yglDotsL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JOhdLeJq, 0, m, &cIf_JOhdLeJq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_JOhdLeJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YKQ9pRWQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_bs8b63EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oF4hamij_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gGnOIbiI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_sjR91VvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwRatdA9, HV_BINOP_POW, 0, m, &cBinop_vwRatdA9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vwRatdA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pM8Pta84, 0, m, &cIf_pM8Pta84_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M2zHAdK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_86Qa1Olm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sMq6OLMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bs8b63EJ, 0, m, &cIf_bs8b63EJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_glT3k7sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1ubFPDbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1ubFPDbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bs8b63EJ, 1, m, &cIf_bs8b63EJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gGnOIbiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_M2zHAdK7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oF4hamij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pM8Pta84, 0, m, &cIf_pM8Pta84_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_86Qa1Olm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwRatdA9, HV_BINOP_POW, 1, m, &cBinop_vwRatdA9_sendMessage);
  cMsg_sjR91VvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_pM8Pta84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Y4rbOhb5, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_yglDotsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JOhdLeJq, 1, m, &cIf_JOhdLeJq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YKQ9pRWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1sVIpnR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_d1sVIpnR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFqXM780, HV_BINOP_EQ, 1, m, &cBinop_KFqXM780_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_voXEDMFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yvr1nFy2, HV_BINOP_ADD, 0, m, &cBinop_Yvr1nFy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Yvr1nFy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_glT3k7sa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sMq6OLMf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d1sVIpnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pM8Pta84, 1, m, &cIf_pM8Pta84_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KFqXM780_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LaAqfV5F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LaAqfV5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y4rbOhb5, m);
}

void Heavy_WSTD_FL3NGR::cCast_X3969AVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NlecnWKm, 0, m, &cVar_NlecnWKm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fKypnKQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_voXEDMFz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_UvgDiD7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yvr1nFy2, HV_BINOP_ADD, 1, m, &cBinop_Yvr1nFy2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1sVIpnR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_d1sVIpnR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFqXM780, HV_BINOP_EQ, 0, m, &cBinop_KFqXM780_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_73Fvhk4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3wxkYUbD, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_uHUvVBJ4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g9RLPGP9, 0, m, &cSlice_g9RLPGP9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_L8Bqsr3D_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_g9RLPGP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DhYJZssl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DhYJZssl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_CAKLTTrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DhYJZssl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DhYJZssl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H7xCgM0u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_L8Bqsr3D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6jchruG3, 0, m, &cSlice_6jchruG3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HC42THMZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_6jchruG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JCUIKXxm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JCUIKXxm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_rPHnOPvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JCUIKXxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JCUIKXxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qkINjJTc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_oZZGGT4t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zWgwpn6M, 0, m, &cSlice_zWgwpn6M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OuY8sXTp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_zWgwpn6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_28lwpNgL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_28lwpNgL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zP8Uk1bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_28lwpNgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_28lwpNgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MJwsksKV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_OuY8sXTp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9uN4p2tH, 0, m, &cSlice_9uN4p2tH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_9uN4p2tH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gE9d5UDK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gE9d5UDK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_dES19fuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gE9d5UDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_gE9d5UDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bOJYoEDA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dxPBEC2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N3izDh66, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3W5JV2cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FBA0UhNW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KCSqKp6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7aBKiUoj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_DKdN7HMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f37iE9tS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ShC3Z99I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pVvWkTtN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_apzIh4KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ViZaCAHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ViZaCAHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkBQKe59, HV_BINOP_DIVIDE, 1, m, &cBinop_fkBQKe59_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pqx9wshC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_FdvwDH3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vPeukbkq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_84HTLoxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FdvwDH3R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vPeukbkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkBQKe59, HV_BINOP_DIVIDE, 0, m, &cBinop_fkBQKe59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pqx9wshC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_84HTLoxD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fkBQKe59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cm5GbFTA, HV_BINOP_MULTIPLY, 1, m, &cBinop_cm5GbFTA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cm5GbFTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OWrUZc8Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_guzYMxSR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_XQ3gOrdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PnonQaPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_JCW2FLBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1Ezf57mC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_k83kqfQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NSLwYdvS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NSLwYdvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cm5GbFTA, HV_BINOP_MULTIPLY, 0, m, &cBinop_cm5GbFTA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dOGn9qki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_giNbUepc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_giNbUepc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nfJQCFac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TzRsyw5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tctckCyL, 1, m, &cVar_tctckCyL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_tctckCyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IqXXQHSB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ldT5aYuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2WZckWUP, HV_BINOP_MULTIPLY, 1, m, &cBinop_2WZckWUP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lzIyyQJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ldT5aYuo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_myHvY7pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kuhrUtjP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kuhrUtjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TV29g51k, HV_BINOP_MULTIPLY, 1, m, &cBinop_TV29g51k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yzkE7END_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n5AFFLYs, HV_BINOP_MULTIPLY, 1, m, &cBinop_n5AFFLYs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KuB3xqLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yzkE7END_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J16NfouD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqF2dX3K, HV_BINOP_MULTIPLY, 1, m, &cBinop_FqF2dX3K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YgoFjFvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KmWlSAfR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KmWlSAfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IpZS6mLp, HV_BINOP_MULTIPLY, 1, m, &cBinop_IpZS6mLp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_GCMy22i8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J1xLLZQf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_k83kqfQD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QYVTWQxA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kRb6lUIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dOGn9qki_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OWrUZc8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_XQ3gOrdt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_guzYMxSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JCW2FLBa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_PnonQaPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DcfDeHzy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1Ezf57mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_29SIIQGF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ZodcqmU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2ru8sHG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nfJQCFac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XF79zCai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XF79zCai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPFHmUx6, HV_BINOP_MULTIPLY, 1, m, &cBinop_pPFHmUx6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pPFHmUx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kLcOVhvf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kLcOVhvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZodcqmU0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IqXXQHSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_P1yW0HFj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P1yW0HFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wD0W7nRf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ISSa0wtE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pJSM9jJe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IBKLG7pa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hw6oTiVu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zGFsLjea_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2WZckWUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dxPBEC2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TV29g51k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3W5JV2cS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_n5AFFLYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCSqKp6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FqF2dX3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DKdN7HMU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IpZS6mLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ShC3Z99I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_VAuax5MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kRb6lUIq, 1, m, &cVar_kRb6lUIq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wiKZDD8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GCMy22i8, 0, m, &cVar_GCMy22i8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zGFsLjea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2WZckWUP, HV_BINOP_MULTIPLY, 0, m, &cBinop_2WZckWUP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pJSM9jJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqF2dX3K, HV_BINOP_MULTIPLY, 0, m, &cBinop_FqF2dX3K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hw6oTiVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TV29g51k, HV_BINOP_MULTIPLY, 0, m, &cBinop_TV29g51k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ISSa0wtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IpZS6mLp, HV_BINOP_MULTIPLY, 0, m, &cBinop_IpZS6mLp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IBKLG7pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n5AFFLYs, HV_BINOP_MULTIPLY, 0, m, &cBinop_n5AFFLYs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wD0W7nRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_QYVTWQxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tctckCyL, 0, m, &cVar_tctckCyL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J1xLLZQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kRb6lUIq, 0, m, &cVar_kRb6lUIq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ppndOwMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ScFWU1q4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BnnyAAhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yAcevV8s, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wbnk1ul5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hit30lnj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_C2LasWU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eVqcG9Ta, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qV3wDqxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZeLlp8Ze_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ZeLlp8Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWFoABdM, HV_BINOP_DIVIDE, 1, m, &cBinop_cWFoABdM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XhPxJorF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TtCESLDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_gaUeyxPC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_L2C0otWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_TtCESLDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gaUeyxPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWFoABdM, HV_BINOP_DIVIDE, 0, m, &cBinop_cWFoABdM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XhPxJorF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L2C0otWy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cWFoABdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSCazSt5, HV_BINOP_MULTIPLY, 1, m, &cBinop_MSCazSt5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MSCazSt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rzcQQrXW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PLvqWsk7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_dvcIkyj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f5y4sebc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_85Ak9yRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JqCMreZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wP3Kvuoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_hebPTZ9k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hebPTZ9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSCazSt5, HV_BINOP_MULTIPLY, 0, m, &cBinop_MSCazSt5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gU6A1bhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AWgqkIXx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AWgqkIXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VEdNi3b4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ijBFNA5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IPhFjFd, HV_BINOP_MULTIPLY, 1, m, &cBinop_5IPhFjFd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IbitUsuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f8djp4gO, 1, m, &cVar_f8djp4gO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PcYiqzsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdLUSDxW, HV_BINOP_MULTIPLY, 1, m, &cBinop_OdLUSDxW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4aFsshNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uw6ZYpTe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uw6ZYpTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUUrbipj, HV_BINOP_MULTIPLY, 1, m, &cBinop_GUUrbipj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_f8djp4gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vYSLvbZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_yukE54co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pXqLSWrA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wP3Kvuoe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sc0cUT6N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_JqXdK6Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gU6A1bhT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PLvqWsk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_85Ak9yRM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rzcQQrXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_dvcIkyj7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_f5y4sebc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QiIOXlzY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JqCMreZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YuNwMWF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_t7whW07L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vkOgxuZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VEdNi3b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CHUhkols_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CHUhkols_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqQG5gaZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_jqQG5gaZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jqQG5gaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7Lg036Il_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7Lg036Il_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t7whW07L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vYSLvbZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SiOph7f2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SiOph7f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CEb4TIAM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7tNLI0Rp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l285qvJr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePD3VfZI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WwTbg1YO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ppndOwMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5IPhFjFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BnnyAAhw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OdLUSDxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wbnk1ul5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GUUrbipj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C2LasWU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_uUNVFPWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JqXdK6Bg, 1, m, &cVar_JqXdK6Bg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5tRVcUDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yukE54co, 0, m, &cVar_yukE54co_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pXqLSWrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JqXdK6Bg, 0, m, &cVar_JqXdK6Bg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Sc0cUT6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f8djp4gO, 0, m, &cVar_f8djp4gO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_l285qvJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IPhFjFd, HV_BINOP_MULTIPLY, 0, m, &cBinop_5IPhFjFd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7tNLI0Rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdLUSDxW, HV_BINOP_MULTIPLY, 0, m, &cBinop_OdLUSDxW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ePD3VfZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WwTbg1YO, HV_BINOP_MULTIPLY, 0, m, &cBinop_WwTbg1YO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CEb4TIAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUUrbipj, HV_BINOP_MULTIPLY, 0, m, &cBinop_GUUrbipj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RbktB7XB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7lAoKRgz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VoTvKnGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GJpXT7ko, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GihUbU4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QYHOuEDN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BABh0NMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jnrOj0Cq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VC7fVJFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YCOqUTuy, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bJq6Q036_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3JKPPh0j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3JKPPh0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POHbDqxP, HV_BINOP_DIVIDE, 1, m, &cBinop_POHbDqxP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ly739Ru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Hx3EGy4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Zw9CfWHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7jtVqdaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Hx3EGy4v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Zw9CfWHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POHbDqxP, HV_BINOP_DIVIDE, 0, m, &cBinop_POHbDqxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7ly739Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jtVqdaX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_POHbDqxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnvCuyVu, HV_BINOP_MULTIPLY, 1, m, &cBinop_GnvCuyVu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GnvCuyVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpy21SZE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bMRCLxX2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_oFHejbqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IWZHVTIM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_aMLCgR7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9XO9buNW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hGx49VPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sZISLwsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sZISLwsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnvCuyVu, HV_BINOP_MULTIPLY, 0, m, &cBinop_GnvCuyVu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gPxoH5JR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_iT3ga2Fw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iT3ga2Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DVmlHg24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_isZkB4Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0AcGl8h8, HV_BINOP_MULTIPLY, 1, m, &cBinop_0AcGl8h8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kbYXVkCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WtcBibgA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WtcBibgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_isZkB4Or_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_scSvlSNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LhGDNNfd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LhGDNNfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZsmSx84, HV_BINOP_MULTIPLY, 1, m, &cBinop_LZsmSx84_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WHsTZ4FL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Z555QEa, HV_BINOP_MULTIPLY, 1, m, &cBinop_8Z555QEa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZK8nbmTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zf7PewAy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zf7PewAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WHsTZ4FL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qd0BW1sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IviAANdG, 1, m, &cVar_IviAANdG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NaEjxPac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NXpL7RAR, HV_BINOP_MULTIPLY, 1, m, &cBinop_NXpL7RAR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_umOC9fhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WCXi3gGr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WCXi3gGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wM2YMp34, HV_BINOP_MULTIPLY, 1, m, &cBinop_wM2YMp34_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_IviAANdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mtVOXSqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ejoO4Si4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7x3QmNxo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_hGx49VPS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LHcnhs7E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TNOWVyyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gPxoH5JR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xpy21SZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oFHejbqC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bMRCLxX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_aMLCgR7A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_IWZHVTIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ocyzREFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9XO9buNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Zv4Bqwsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QjBwC0GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9TQVfR2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DVmlHg24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_O4nrWRRS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O4nrWRRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nhDaBjqm, HV_BINOP_MULTIPLY, 1, m, &cBinop_nhDaBjqm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nhDaBjqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_myPHkUyU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_myPHkUyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QjBwC0GO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mtVOXSqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3VG4VpNh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3VG4VpNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dDlj9QlF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FOHzEJq1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nPVrxfN6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5RcY0hD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OCJNXefn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wMh2ZLte_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0AcGl8h8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RbktB7XB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LZsmSx84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VoTvKnGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8Z555QEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GihUbU4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NXpL7RAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BABh0NMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wM2YMp34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VC7fVJFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_TTc8DXbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ejoO4Si4, 0, m, &cVar_ejoO4Si4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lMByDUEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TNOWVyyP, 1, m, &cVar_TNOWVyyP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wMh2ZLte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0AcGl8h8, HV_BINOP_MULTIPLY, 0, m, &cBinop_0AcGl8h8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nPVrxfN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NXpL7RAR, HV_BINOP_MULTIPLY, 0, m, &cBinop_NXpL7RAR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OCJNXefn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZsmSx84, HV_BINOP_MULTIPLY, 0, m, &cBinop_LZsmSx84_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FOHzEJq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wM2YMp34, HV_BINOP_MULTIPLY, 0, m, &cBinop_wM2YMp34_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_l5RcY0hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Z555QEa, HV_BINOP_MULTIPLY, 0, m, &cBinop_8Z555QEa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dDlj9QlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_LHcnhs7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IviAANdG, 0, m, &cVar_IviAANdG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7x3QmNxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TNOWVyyP, 0, m, &cVar_TNOWVyyP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kF1RAjoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_73Fvhk4z, 1, m, &cIf_73Fvhk4z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_X7hpMV2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3wxkYUbD, m);
}

void Heavy_WSTD_FL3NGR::cBinop_d3QKG0zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X7hpMV2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_t5pZc6XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_73Fvhk4z, 0, m, &cIf_73Fvhk4z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_f17j4Qme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OgtgyK7a, HV_BINOP_DIVIDE, 0, m, &cBinop_OgtgyK7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hrpfoaSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YnSGspsC, HV_BINOP_DIVIDE, 1, m, &cBinop_YnSGspsC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OgtgyK7a, HV_BINOP_DIVIDE, 1, m, &cBinop_OgtgyK7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_IgwXjvHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdJ9Q1AI, HV_BINOP_DIVIDE, 0, m, &cBinop_tdJ9Q1AI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_EmRP7MeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdJ9Q1AI, HV_BINOP_DIVIDE, 1, m, &cBinop_tdJ9Q1AI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jvAVD9jG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YnSGspsC, HV_BINOP_DIVIDE, 0, m, &cBinop_YnSGspsC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Eo9lBYCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f17j4Qme, 0, m, &cVar_f17j4Qme_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1NVkBS9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hrpfoaSD, 0, m, &cVar_hrpfoaSD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YnSGspsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_IgwXjvHM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OgtgyK7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_EmRP7MeG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tdJ9Q1AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_SZnbp2OD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Tx3N3brE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_PBcbvER5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jFCntnj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_wRGAdIsf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SZnbp2OD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jFCntnj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wRGAdIsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Tx3N3brE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PBcbvER5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3YhjVxwj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_r0TI1wHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VzWDgWVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_QKuHPLjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hz9i2EvQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_M7istRv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3yfPn4ae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_t9hNfcIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_95zu03PF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0MnmqKTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g52QOSkB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_k7q8YUdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FhPSfh8v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_xawyCRKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3kEiu8tY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ytXYLyff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vcip0Dk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_nqkTUzU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BMUn2Zzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_t1Nj9i9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HULmlA1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_BFlq6i32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nbRSRtIo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zkZqGFiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PXjgQFt6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KWuQacNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZYX64UnQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZYX64UnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_gu23g1lV, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LiTuEQiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CEf9wCav_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CEf9wCav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BL5kVXTm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_f2RBrPzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lx1Jjrf4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_AUKEg7Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fl09UDpq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MmgYKiTO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BL5kVXTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_usSTnGav, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Lx1Jjrf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AUKEg7Tp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fl09UDpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_A0OdtnvF, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BJhaHLAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tGUmtwsD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_tGUmtwsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aeELUvxM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_qNDRt4DT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HjDZDW2N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_kfNIkMXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zXFxlSg8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zaE3L2gr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aeELUvxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_faBSrxzN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_HjDZDW2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kfNIkMXx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zXFxlSg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_j25z59Nz, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BJQik3m5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZUnd3cmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZUnd3cmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vRGR8qHo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_94Zs8fSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VCMW3MlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Gl9Oce7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Zc1SacK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vRGR8qHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UY5DBMB2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UY5DBMB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R5MZuk4f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c6K1pxvX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_c6K1pxvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D5ncCKmO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_R5MZuk4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xVZQXxue_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xVZQXxue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lq4Zx5Ik_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_D5ncCKmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F6lwtAuP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F6lwtAuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mKJNGFlZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lq4Zx5Ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_94Zs8fSi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mKJNGFlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Gl9Oce7I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d6gzR5Xa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fTAdoBSQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fTAdoBSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W1lHO5Fy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xMvzw47O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X312KEpB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_X312KEpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gLWfF0z2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_cTYX5IdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cTYX5IdP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GLY8d7YN, 0, m, &cDelay_GLY8d7YN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cTYX5IdP, 0, m, &cDelay_cTYX5IdP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EYbVue7d, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_GLY8d7YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GLY8d7YN, m);
  cMsg_C2zr6BKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_khyCDENa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ElU0kUhH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_5KPWvJuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pz8WiwAV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_zFSS8M7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQk0WBeY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cTYX5IdP, 2, m, &cDelay_cTYX5IdP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zqKM3gcU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pz8WiwAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zFSS8M7r, 0, m, &hTable_zFSS8M7r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gLWfF0z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_5KPWvJuC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C2zr6BKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zFSS8M7r, 0, m, &hTable_zFSS8M7r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zqKM3gcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cTYX5IdP, 0, m, &cDelay_cTYX5IdP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OQk0WBeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_GLY8d7YN, 2, m, &cDelay_GLY8d7YN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ElU0kUhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EYbVue7d, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ifnGoaSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CPESDrKu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CPESDrKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wp7FXIgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_xxY8nZWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xxY8nZWJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BMNeiRBv, 0, m, &cDelay_BMNeiRBv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xxY8nZWJ, 0, m, &cDelay_xxY8nZWJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Xkd38uaD, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_BMNeiRBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BMNeiRBv, m);
  cMsg_ZXkxHNIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EKuNokcX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9aOW9I2D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_t6AnEctb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwA6fc2B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_QUyZYC5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_grq2XDTz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xxY8nZWJ, 2, m, &cDelay_xxY8nZWJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z600ls3L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xwA6fc2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QUyZYC5c, 0, m, &hTable_QUyZYC5c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wp7FXIgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_t6AnEctb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZXkxHNIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QUyZYC5c, 0, m, &hTable_QUyZYC5c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_z600ls3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xxY8nZWJ, 0, m, &cDelay_xxY8nZWJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_grq2XDTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BMNeiRBv, 2, m, &cDelay_BMNeiRBv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9aOW9I2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Xkd38uaD, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_lnaQdjP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARyvrQpR, HV_BINOP_MULTIPLY, 0, m, &cBinop_ARyvrQpR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Rrge61bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rlJXwonW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rlJXwonW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JCQHuOU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ARyvrQpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AZoUJBBZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Pg7wlLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARyvrQpR, HV_BINOP_MULTIPLY, 1, m, &cBinop_ARyvrQpR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JCQHuOU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2Pg7wlLI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AZoUJBBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Zl6vPhad_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Zl6vPhad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lrzhJZgX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Gb3ppdit, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lrzhJZgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6VB28Jrz, m);
}

void Heavy_WSTD_FL3NGR::cVar_hScgjD4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_stvsCfbf, HV_BINOP_MULTIPLY, 0, m, &cBinop_stvsCfbf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Pt4e8o5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jKs5LH0x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_jKs5LH0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dP2sK9Pd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_stvsCfbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SbCsERmP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qa2lZtR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_stvsCfbf, HV_BINOP_MULTIPLY, 1, m, &cBinop_stvsCfbf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dP2sK9Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qa2lZtR2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SbCsERmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XB87Qhjg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XB87Qhjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EWBywmvt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_okxRsif4, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EWBywmvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nv2yY4WC, m);
}

void Heavy_WSTD_FL3NGR::cMsg_W1lHO5Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_stGfxQ4t, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_8QQmNciv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_gmUVV7z9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lGPgcWZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Kk1vHFMe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_D9Umv0XS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_8QQmNciv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sj6eqH7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z98uVoy0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z98uVoy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0pKNBuRQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_0pKNBuRQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kk1vHFMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_sj6eqH7h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0pKNBuRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_phiuW5uD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gmUVV7z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0pKNBuRQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_0pKNBuRQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_phiuW5uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RPb8Cf7s, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_w8vQ7dvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_7rbADNAO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7rbADNAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lGPgcWZr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D9Umv0XS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_997hGFtC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MMnz7oyU, 0, m, &cSlice_MMnz7oyU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sgLcttBO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_MMnz7oyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cvfQ8Tp0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cvfQ8Tp0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_HnUiwS0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cvfQ8Tp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cvfQ8Tp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cKCKqSY8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_sgLcttBO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qnlGptfV, 0, m, &cSlice_qnlGptfV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8NUOyAKK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_qnlGptfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_X68oaWRR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_X68oaWRR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DftVKNXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X68oaWRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_X68oaWRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RNBsXfGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_8NUOyAKK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cZ0l2fnf, 0, m, &cSlice_cZ0l2fnf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mhxoddyf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_cZ0l2fnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nkvFnxBd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nkvFnxBd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_9xCkxOmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nkvFnxBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_nkvFnxBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EhRHNDR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mhxoddyf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jMI2OXgR, 0, m, &cSlice_jMI2OXgR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jMI2OXgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iDKzYE8u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iDKzYE8u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_kYB40tmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iDKzYE8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_iDKzYE8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fIVDDeq5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VCMW3MlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bH09qJsC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5Zc1SacK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L6dfXcxj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_zEqBssia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ohgcIFES_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ohgcIFES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_xQiOGI05, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wgDtFo3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xTODPnW1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_xTODPnW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YWRB4J6i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_2TrH8XTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rsxBk4Th_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_mmAk2IQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OhO0OSVT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9SPDjo4A, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YWRB4J6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_E2D7hDSg, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rsxBk4Th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mmAk2IQp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OhO0OSVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_guVfMHe6, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EEBCyiOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_R1CjCly5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_R1CjCly5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iURMqeNp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_koYQNZig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Gdti1OS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_qwHuNeyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZrNacsJL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_D5n6QwL7, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iURMqeNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nNmz4r3m, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7Gdti1OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qwHuNeyJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZrNacsJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rrdX9lu4, m);
}

void Heavy_WSTD_FL3NGR::cBinop_F62RKHGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CAUWLdsx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CAUWLdsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_fBQEhjXa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_sDFs0nmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7QVdU1Pi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_2BNEXEvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IDkDZcme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fBQEhjXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LKvu0jnd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LKvu0jnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w07iISPB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jh8RGxch_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jh8RGxch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QFcJ8JJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_w07iISPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_r8ftB5xt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r8ftB5xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QtHsi8NU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3QFcJ8JJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x1mNifVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x1mNifVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BHydEvQl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QtHsi8NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_sDFs0nmq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BHydEvQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_2BNEXEvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PsCOjkj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OxhnSTYC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OxhnSTYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WPSQwuRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gmkeyYuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hd9dEPW0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_hd9dEPW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_M1VXppH3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Tl4bCYBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Tl4bCYBz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YmVEoCr4, 0, m, &cDelay_YmVEoCr4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tl4bCYBz, 0, m, &cDelay_Tl4bCYBz_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eDOZXxAF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_YmVEoCr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YmVEoCr4, m);
  cMsg_GhbqVbLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_rBSHxTtm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Axi9jGa2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_OXapXKip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i0dVmqjw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_QeCXKJhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBNCqNbG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tl4bCYBz, 2, m, &cDelay_Tl4bCYBz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_718srYTT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i0dVmqjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QeCXKJhw, 0, m, &hTable_QeCXKJhw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M1VXppH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_OXapXKip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GhbqVbLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QeCXKJhw, 0, m, &hTable_QeCXKJhw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_718srYTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tl4bCYBz, 0, m, &cDelay_Tl4bCYBz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QBNCqNbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_YmVEoCr4, 2, m, &cDelay_YmVEoCr4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Axi9jGa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eDOZXxAF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bQGEkVwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5UNpYCz3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_5UNpYCz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KYUXSOLY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_TLcIpOaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TLcIpOaV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y5S2ihQB, 0, m, &cDelay_Y5S2ihQB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLcIpOaV, 0, m, &cDelay_TLcIpOaV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_obeV3vmO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_Y5S2ihQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y5S2ihQB, m);
  cMsg_3qpjlLhL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Efv7sffq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_JGwgwxpJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_1ThWlU3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WOjQAeUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_XY0fzTTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hyQWFqRV_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLcIpOaV, 2, m, &cDelay_TLcIpOaV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fNOAYVHD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WOjQAeUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XY0fzTTU, 0, m, &hTable_XY0fzTTU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KYUXSOLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_1ThWlU3V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3qpjlLhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XY0fzTTU, 0, m, &hTable_XY0fzTTU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fNOAYVHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TLcIpOaV, 0, m, &cDelay_TLcIpOaV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hyQWFqRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y5S2ihQB, 2, m, &cDelay_Y5S2ihQB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JGwgwxpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_obeV3vmO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_8u1AqJ0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UnuVloBB, HV_BINOP_MULTIPLY, 0, m, &cBinop_UnuVloBB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Nq7w6g85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GoZ9j1RX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_GoZ9j1RX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4mRXEsJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UnuVloBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1QQdmoPj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IEuV8qrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UnuVloBB, HV_BINOP_MULTIPLY, 1, m, &cBinop_UnuVloBB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4mRXEsJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IEuV8qrc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1QQdmoPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BsU4PCVL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BsU4PCVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Q9eT1RDw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HlMysWMX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Q9eT1RDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LwOVWhra, m);
}

void Heavy_WSTD_FL3NGR::cVar_vPYkbbKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z9UtfEvy, HV_BINOP_MULTIPLY, 0, m, &cBinop_z9UtfEvy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sR8mP9Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BUk7TBhM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_BUk7TBhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jRBtbsfm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_z9UtfEvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4VWpr8Pj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ph3wyruf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z9UtfEvy, HV_BINOP_MULTIPLY, 1, m, &cBinop_z9UtfEvy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jRBtbsfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ph3wyruf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4VWpr8Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TU2sRr44_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TU2sRr44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Re4mkHFT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lTcbdWRK, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Re4mkHFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HG9PX9aW, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WPSQwuRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yfi0YNnZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_3Ko6Ah8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_3Sqoanpa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HjR1lWPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oug88TaW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ngjerYEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3Ko6Ah8q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vijRGFsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XQQOO2rF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XQQOO2rF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cj82k0EH, HV_BINOP_MULTIPLY, 1, m, &cBinop_cj82k0EH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oug88TaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vijRGFsv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cj82k0EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oLVs8qo1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3Sqoanpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cj82k0EH, HV_BINOP_MULTIPLY, 0, m, &cBinop_cj82k0EH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oLVs8qo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5P3i24DQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_EIQ33Wpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_v4vvB3gn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v4vvB3gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HjR1lWPA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ngjerYEL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lVrsoq9x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vQjoaHCs, 0, m, &cSlice_vQjoaHCs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JIcxbC02_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vQjoaHCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OJmg01js_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OJmg01js_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gbwWbLJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OJmg01js_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OJmg01js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tFSAIt1I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JIcxbC02_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_70QRgWqO, 0, m, &cSlice_70QRgWqO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hI6dYBVv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_70QRgWqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CT39ZfH5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CT39ZfH5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_i9OCorJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CT39ZfH5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CT39ZfH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JWydOYXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_hI6dYBVv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_O9MsYH41, 0, m, &cSlice_O9MsYH41_sendMessage);
      break;
    }
    default: {
      cSwitchcase_34KQET4D_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_O9MsYH41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zHaNlw1u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zHaNlw1u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wHqFQ6un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zHaNlw1u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zHaNlw1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fEIBkvFv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_34KQET4D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7VUPDsh2, 0, m, &cSlice_7VUPDsh2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_7VUPDsh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jwPR2sKu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jwPR2sKu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_AsQfpLk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jwPR2sKu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jwPR2sKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OMucdLQc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7QVdU1Pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bfn7scDq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IDkDZcme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uSFrZKT9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_hDW9MvI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rPTq6Cqc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rPTq6Cqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_8b7OxT56, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_S0GUja9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6Jt1diyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_6Jt1diyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wuk7wy8O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sgfVk7Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_msuqCBiY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_0WaJdFhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Fbj9LYqO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w1qjihjn, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wuk7wy8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Eh06IYON, m);
}

void Heavy_WSTD_FL3NGR::cMsg_msuqCBiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0WaJdFhv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fbj9LYqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mpp4hzrt, m);
}

void Heavy_WSTD_FL3NGR::cMsg_upgPhcWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ORPxaxZU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ORPxaxZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0gv5kTFk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Y136Y0ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bcCMQcZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_6KWBkuQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sSeHsP2n_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uweqV1Go, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0gv5kTFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DTwTlh99, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bcCMQcZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6KWBkuQG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sSeHsP2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_C09TBsEn, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3IK8FSdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5v1Ao30z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5v1Ao30z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_uI50RzlD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_IAJVE4vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vOvuzZRZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_HyGUhPDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LnaIvXap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uI50RzlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aavIHlOx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aavIHlOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0xNBktst_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IyrxayAf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0xNBktst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NTqS2jk8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IyrxayAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pt7BxuFo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NTqS2jk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aKqu3Khv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pt7BxuFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xbYzbV0k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xbYzbV0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CMhBzEBS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aKqu3Khv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_IAJVE4vO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CMhBzEBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_HyGUhPDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wRtPV9TF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nIFA2LbX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nIFA2LbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ccObfok3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ibZqUXsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_e1NX7ZTp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_e1NX7ZTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h94auqwU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_lyHd4ICk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lyHd4ICk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnE1sZ6C, 0, m, &cDelay_nnE1sZ6C_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lyHd4ICk, 0, m, &cDelay_lyHd4ICk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_omFF6cTp, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_nnE1sZ6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nnE1sZ6C, m);
  cMsg_EeDpAUuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_8HXB1eUd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nao8TYA8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ziPnzig7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ujQrXPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_JRvGoMPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NYY4mLmQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lyHd4ICk, 2, m, &cDelay_lyHd4ICk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_itKaIWmu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0ujQrXPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JRvGoMPY, 0, m, &hTable_JRvGoMPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h94auqwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ziPnzig7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EeDpAUuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JRvGoMPY, 0, m, &hTable_JRvGoMPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_itKaIWmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lyHd4ICk, 0, m, &cDelay_lyHd4ICk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NYY4mLmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnE1sZ6C, 2, m, &cDelay_nnE1sZ6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nao8TYA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_omFF6cTp, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QCUR278Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_peuh9SQ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_peuh9SQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NGOIrTss_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Y09XCAYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y09XCAYX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XtyeifGo, 0, m, &cDelay_XtyeifGo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y09XCAYX, 0, m, &cDelay_Y09XCAYX_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_i9fMCQ4B, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_XtyeifGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XtyeifGo, m);
  cMsg_bx9KaEFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5B6dQkpX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_e8FseOn2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wLd3RM2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgAsUKvF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_74GBMlFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ZwNImk6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y09XCAYX, 2, m, &cDelay_Y09XCAYX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3GTFUjc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lgAsUKvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_74GBMlFw, 0, m, &hTable_74GBMlFw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NGOIrTss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_wLd3RM2e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bx9KaEFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_74GBMlFw, 0, m, &hTable_74GBMlFw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r3GTFUjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y09XCAYX, 0, m, &cDelay_Y09XCAYX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4ZwNImk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_XtyeifGo, 2, m, &cDelay_XtyeifGo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_e8FseOn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_i9fMCQ4B, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_tVSBClxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tO0lypO, HV_BINOP_MULTIPLY, 0, m, &cBinop_5tO0lypO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_D4BSDBIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GKBFAW5R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_GKBFAW5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCeEop46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5tO0lypO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zoNRsE4t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uquOVhfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tO0lypO, HV_BINOP_MULTIPLY, 1, m, &cBinop_5tO0lypO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NCeEop46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uquOVhfi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zoNRsE4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_el7FZGWH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_el7FZGWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ok59AG8P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cS7BY53p, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ok59AG8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UG6HMhnf, m);
}

void Heavy_WSTD_FL3NGR::cVar_G1b8be9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CVLCMWzI, HV_BINOP_MULTIPLY, 0, m, &cBinop_CVLCMWzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3RylINTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OigNS6qU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_OigNS6qU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1geAcydr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CVLCMWzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rTXHTVMV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YgDRMdLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CVLCMWzI, HV_BINOP_MULTIPLY, 1, m, &cBinop_CVLCMWzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1geAcydr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YgDRMdLN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rTXHTVMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MiN5I1lT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MiN5I1lT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FzyaZFqW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_STsFoYTL, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FzyaZFqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BFaA2E5L, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ccObfok3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwd7mao0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_uWuXL9fK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_1mZNmj9Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6lQbHY3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_uWuXL9fK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8YKmIMV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_neHPZnWB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TBpVaJIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kvFgJWB9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kvFgJWB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L5mFo2Sd, HV_BINOP_MULTIPLY, 1, m, &cBinop_L5mFo2Sd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_neHPZnWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TBpVaJIB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L5mFo2Sd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2UiS830Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1mZNmj9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L5mFo2Sd, HV_BINOP_MULTIPLY, 0, m, &cBinop_L5mFo2Sd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2UiS830Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zeC4tKMb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_r0xgYdDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_IkKoLDMG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IkKoLDMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8YKmIMV6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6lQbHY3g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7cicDsqq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w5tDkXIW, 0, m, &cSlice_w5tDkXIW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tG3makXn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_w5tDkXIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_basCaVdh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_basCaVdh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_V2hqCCuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_basCaVdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_basCaVdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Yv06xjEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_tG3makXn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1uOmlfJd, 0, m, &cSlice_1uOmlfJd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1Q48uEA5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1uOmlfJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9p8kVRDY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9p8kVRDY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_fgcS2GyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9p8kVRDY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9p8kVRDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XakEBqSd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_1Q48uEA5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RCQYIfxw, 0, m, &cSlice_RCQYIfxw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ue45D07I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_RCQYIfxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JBVWxhHq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JBVWxhHq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_SIEin6FD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JBVWxhHq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JBVWxhHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AXWgcvlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ue45D07I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jGa9vrjs, 0, m, &cSlice_jGa9vrjs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jGa9vrjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5tkXJmyu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5tkXJmyu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_w53ho9nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5tkXJmyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5tkXJmyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KVyhLDIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vOvuzZRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ODVCT8sL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LnaIvXap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rFFazbjn, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IliKlp3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUPUv5hD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uHUvVBJ4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9wlIIHf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUPUv5hD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uHUvVBJ4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AtEqdjiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUPUv5hD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uHUvVBJ4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pJGVpTSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUPUv5hD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uHUvVBJ4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3YhjVxwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUPUv5hD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uHUvVBJ4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CQuztFNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RDDm14Lm, 0, m, &cVar_RDDm14Lm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_quA03UZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_32wA7G8C, 0, m, &cVar_32wA7G8C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jBSCX0qC, 0, m, &cVar_jBSCX0qC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Bbv6kAy, 0, m, &cVar_7Bbv6kAy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_95zu03PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_997hGFtC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VzWDgWVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_997hGFtC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Hz9i2EvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_997hGFtC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3yfPn4ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_997hGFtC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_HVLF8cal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t9hNfcIQ, 0, m, &cVar_t9hNfcIQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gfiXx74N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r0TI1wHb, 0, m, &cVar_r0TI1wHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QfYlvKJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M7istRv3, 0, m, &cVar_M7istRv3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vcip0Dk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lVrsoq9x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_g52QOSkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lVrsoq9x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FhPSfh8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lVrsoq9x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3kEiu8tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lVrsoq9x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_R2HCEWsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ytXYLyff, 0, m, &cVar_ytXYLyff_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dc83xFRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0MnmqKTP, 0, m, &cVar_0MnmqKTP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FdRs08yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xawyCRKd, 0, m, &cVar_xawyCRKd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PXjgQFt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7cicDsqq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BMUn2Zzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7cicDsqq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HULmlA1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7cicDsqq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nbRSRtIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7cicDsqq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_FiXouV8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zkZqGFiD, 0, m, &cVar_zkZqGFiD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iJdYvBqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nqkTUzU0, 0, m, &cVar_nqkTUzU0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HIxoQKcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BFlq6i32, 0, m, &cVar_BFlq6i32_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ng9n8zRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_32wA7G8C, 0, m, &cVar_32wA7G8C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_spz3ybVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jBSCX0qC, 0, m, &cVar_jBSCX0qC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1YiusPGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Bbv6kAy, 0, m, &cVar_7Bbv6kAy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5ZbZmUYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PMjCi0E6, 0, m, &cVar_PMjCi0E6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4LUCthbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DWX9meF4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dk57SR0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rQpDtB6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BBVxzBEC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zqWVYJIQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_03yFhOB8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dT9pRnhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OEelAoHi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AZXgnyrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bll1733G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qR6yfns4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rMf3j5QG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X22biFRi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmCvINmL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PivsYGAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qnxa71Lt_sendMessage(_c, 0, m);
  cMsg_Gne81bWU_sendMessage(_c, 0, m);
  cMsg_e58kmsKd_sendMessage(_c, 0, m);
  cMsg_apzIh4KF_sendMessage(_c, 0, m);
  cMsg_qV3wDqxk_sendMessage(_c, 0, m);
  cMsg_bJq6Q036_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X3k8MUn2, 0, m, &cVar_X3k8MUn2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PMjCi0E6, 0, m, &cVar_PMjCi0E6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mH5gY6D0, 0, m, &cVar_mH5gY6D0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GCMy22i8, 0, m, &cVar_GCMy22i8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yukE54co, 0, m, &cVar_yukE54co_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ejoO4Si4, 0, m, &cVar_ejoO4Si4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_evP30tgl, 0, m, &cVar_evP30tgl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n5QcNEOL, 0, m, &cVar_n5QcNEOL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dIA18ndK, 0, m, &cVar_dIA18ndK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hy8PALgj, 0, m, &cVar_hy8PALgj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0gGZL8wC, 0, m, &cVar_0gGZL8wC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QAEaWR7k, 0, m, &cVar_QAEaWR7k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4OMuVNpY, 0, m, &cVar_4OMuVNpY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P602dJ5j, 0, m, &cVar_P602dJ5j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2cYhzwba, 0, m, &cVar_2cYhzwba_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P5tOjSoW, 0, m, &cVar_P5tOjSoW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KWRX6wej, 0, m, &cVar_KWRX6wej_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NlecnWKm, 0, m, &cVar_NlecnWKm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CAKLTTrG, 0, m, &cVar_CAKLTTrG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rPHnOPvO, 0, m, &cVar_rPHnOPvO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zP8Uk1bt, 0, m, &cVar_zP8Uk1bt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dES19fuW, 0, m, &cVar_dES19fuW_sendMessage);
  cMsg_Rrge61bN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lnaQdjP6, 0, m, &cVar_lnaQdjP6_sendMessage);
  cMsg_Pt4e8o5M_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hScgjD4d, 0, m, &cVar_hScgjD4d_sendMessage);
  cMsg_Nq7w6g85_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8u1AqJ0t, 0, m, &cVar_8u1AqJ0t_sendMessage);
  cMsg_sR8mP9Xr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vPYkbbKr, 0, m, &cVar_vPYkbbKr_sendMessage);
  cMsg_D4BSDBIm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tVSBClxV, 0, m, &cVar_tVSBClxV_sendMessage);
  cMsg_3RylINTY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_G1b8be9t, 0, m, &cVar_G1b8be9t_sendMessage);
  cMsg_xMvzw47O_sendMessage(_c, 0, m);
  cMsg_ifnGoaSN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HnUiwS0x, 0, m, &cVar_HnUiwS0x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DftVKNXS, 0, m, &cVar_DftVKNXS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9xCkxOmd, 0, m, &cVar_9xCkxOmd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kYB40tmG, 0, m, &cVar_kYB40tmG_sendMessage);
  cMsg_gmkeyYuq_sendMessage(_c, 0, m);
  cMsg_bQGEkVwD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gbwWbLJT, 0, m, &cVar_gbwWbLJT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i9OCorJF, 0, m, &cVar_i9OCorJF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wHqFQ6un, 0, m, &cVar_wHqFQ6un_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AsQfpLk8, 0, m, &cVar_AsQfpLk8_sendMessage);
  cMsg_ibZqUXsW_sendMessage(_c, 0, m);
  cMsg_QCUR278Q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_V2hqCCuW, 0, m, &cVar_V2hqCCuW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fgcS2GyX, 0, m, &cVar_fgcS2GyX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SIEin6FD, 0, m, &cVar_SIEin6FD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w53ho9nW, 0, m, &cVar_w53ho9nW_sendMessage);
  cMsg_quA03UZ1_sendMessage(_c, 0, m);
  cMsg_CQuztFNw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f2RBrPzc, 0, m, &cVar_f2RBrPzc_sendMessage);
  cMsg_LiTuEQiG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qNDRt4DT, 0, m, &cVar_qNDRt4DT_sendMessage);
  cMsg_BJhaHLAu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2TrH8XTc, 0, m, &cVar_2TrH8XTc_sendMessage);
  cMsg_wgDtFo3a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_koYQNZig, 0, m, &cVar_koYQNZig_sendMessage);
  cMsg_EEBCyiOQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sgfVk7Nw, 0, m, &cVar_sgfVk7Nw_sendMessage);
  cMsg_S0GUja9O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Y136Y0ia, 0, m, &cVar_Y136Y0ia_sendMessage);
  cMsg_upgPhcWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_7fi8ZTgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GAhEYU8, HV_BINOP_MULTIPLY, 0, m, &cBinop_9GAhEYU8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qQoC8itl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VxMxsyD5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yc6PbvY3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ufTkXAzj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HzVuwDyJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GLppN1sJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_S3x3L0si_sendMessage);
  cMsg_L9TBPslw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_5a0dnoPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmN1IyN1, HV_BINOP_MULTIPLY, 0, m, &cBinop_KmN1IyN1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XEwEiSEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_KsZCc6uk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DPEyCJjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bfLumqpK, HV_BINOP_MULTIPLY, 1, m, &cBinop_bfLumqpK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Vquik7Zw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MkXya4XV_sendMessage);
  cMsg_DRv2kEU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_XfjYQiW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RgBL9bOa, HV_BINOP_MULTIPLY, 0, m, &cBinop_RgBL9bOa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_C63HJeUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K8cI8pZe_sendMessage(_c, 0, m);
  cMsg_7luIthzM_sendMessage(_c, 0, m);
  cMsg_j9huh89u_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_20huJM00_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wjlF9XQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TAsW0Kjy_sendMessage);
  cMsg_agBWe9Ar_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_WCLKm6N1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yukE54co, 0, m, &cVar_yukE54co_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bOJYoEDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uUNVFPWB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5tRVcUDb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_H7xCgM0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n9IKcOab_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vPsg1H7k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lE8Zo8ma_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MJwsksKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X3969AVu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UvgDiD7v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fKypnKQp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qkINjJTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mvq7jN9G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7TZUoaK3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yn1IbxCK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DcfDeHzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPFHmUx6, HV_BINOP_MULTIPLY, 0, m, &cBinop_pPFHmUx6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_29SIIQGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lzIyyQJn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_myHvY7pN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KuB3xqLY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_J16NfouD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2ru8sHG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TzRsyw5w_sendMessage);
  cMsg_YgoFjFvx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_QiIOXlzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqQG5gaZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_jqQG5gaZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YuNwMWF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PcYiqzsC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vkOgxuZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WwTbg1YO, HV_BINOP_MULTIPLY, 1, m, &cBinop_WwTbg1YO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ijBFNA5V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IbitUsuH_sendMessage);
  cMsg_4aFsshNo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_ocyzREFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nhDaBjqm, HV_BINOP_MULTIPLY, 0, m, &cBinop_nhDaBjqm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Zv4Bqwsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kbYXVkCn_sendMessage(_c, 0, m);
  cMsg_scSvlSNG_sendMessage(_c, 0, m);
  cMsg_ZK8nbmTk_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_NaEjxPac_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9TQVfR2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Qd0BW1sG_sendMessage);
  cMsg_umOC9fhP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Zwo1yKPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RDDm14Lm, 0, m, &cVar_RDDm14Lm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MGATtlAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_HVLF8cal_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NLCM5LGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gfiXx74N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LRRw0LQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QKuHPLjb, 0, m, &cVar_QKuHPLjb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rn4RZHeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QfYlvKJd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3mFZs1ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_R2HCEWsX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nbD1vylN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Dc83xFRj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_OqZHE7AL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k7q8YUdt, 0, m, &cVar_k7q8YUdt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ID9gI2k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FdRs08yk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2RYBvNPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FiXouV8P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qEaIIXlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_iJdYvBqX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JXrrPlWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t1Nj9i9S, 0, m, &cVar_t1Nj9i9S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hfBm1Fqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_HIxoQKcH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_EhRHNDR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_KWuQacNl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RNBsXfGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_w8vQ7dvO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fIVDDeq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BJQik3m5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cKCKqSY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_d6gzR5Xa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fEIBkvFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_zEqBssia_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JWydOYXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_EIQ33Wpm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_OMucdLQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_F62RKHGw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tFSAIt1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PsCOjkj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_AXWgcvlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_hDW9MvI9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XakEBqSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_r0xgYdDf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_KVyhLDIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3IK8FSdN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Yv06xjEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wRtPV9TF_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ekTb8JhU, VOf(Bf0));
    __hv_line_f(&sLine_WzOBj5FS, VOf(Bf1));
    __hv_line_f(&sLine_Q0gW20hb, VOf(Bf2));
    __hv_line_f(&sLine_VUF7fzhS, VOf(Bf3));
    __hv_line_f(&sLine_9TO1OVeJ, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_DHRwoLZV, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_PAszra08, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_jewEz75O, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_viQs0mTx, VOf(Bf1));
    __hv_line_f(&sLine_XsfNRv1b, VOf(Bf0));
    __hv_line_f(&sLine_z6sT43il, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_vBLI6Xfk, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_KmYDJbjQ, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_VfxwYiKS, VOf(Bf5));
    __hv_line_f(&sLine_g25x8lrH, VOf(Bf1));
    __hv_line_f(&sLine_kNvhcgNC, VOf(Bf2));
    __hv_line_f(&sLine_UqALfCV9, VOf(Bf4));
    __hv_line_f(&sLine_ugMK8VuI, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_vxYlpOKR, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_jvRgxtTs, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_N3izDh66, VOf(Bf6));
    __hv_line_f(&sLine_FBA0UhNW, VOf(Bf2));
    __hv_line_f(&sLine_7aBKiUoj, VOf(Bf1));
    __hv_line_f(&sLine_f37iE9tS, VOf(Bf5));
    __hv_line_f(&sLine_pVvWkTtN, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_CdSNsmgR, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QKVzhCAM, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ScFWU1q4, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_yAcevV8s, VOf(Bf2));
    __hv_line_f(&sLine_hit30lnj, VOf(Bf6));
    __hv_line_f(&sLine_eVqcG9Ta, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_n16HtM5L, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_3wxkYUbD, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_7lAoKRgz, VOf(Bf8));
    __hv_line_f(&sLine_GJpXT7ko, VOf(Bf2));
    __hv_line_f(&sLine_QYHOuEDN, VOf(Bf1));
    __hv_line_f(&sLine_jnrOj0Cq, VOf(Bf7));
    __hv_line_f(&sLine_YCOqUTuy, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_s6T2OepG, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Y4rbOhb5, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_L6dfXcxj, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_gu23g1lV, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_stGfxQ4t, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_Gb3ppdit, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_6VB28Jrz, VOf(Bf8));
    __hv_rpole_f(&sRPole_hn1883kz, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_okxRsif4, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_nv2yY4WC, VOf(Bf10));
    __hv_rpole_f(&sRPole_I3SA3a3g, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_VE2ZVPYJ, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_usSTnGav, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_A0OdtnvF, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_MmgYKiTO, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_6dZd6sx3, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_xneFoeiA, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_bH09qJsC, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_ts9nihXP, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_faBSrxzN, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_j25z59Nz, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_zaE3L2gr, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_mVGqJLoX, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_PyPIvteG, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_RPb8Cf7s, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_EYbVue7d, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_Xkd38uaD, VIf(Bf3));
    __hv_varwrite_f(&sVarf_YukM7lya, VIf(Bf11));
    __hv_line_f(&sLine_uSFrZKT9, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_xQiOGI05, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_yfi0YNnZ, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_HlMysWMX, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_LwOVWhra, VOf(Bf10));
    __hv_rpole_f(&sRPole_gqQzXJaS, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_lTcbdWRK, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_HG9PX9aW, VOf(Bf5));
    __hv_rpole_f(&sRPole_4U11Kbcx, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_AruzvT1e, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_E2D7hDSg, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_guVfMHe6, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_9SPDjo4A, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_As9qGLPi, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_iwEASf7o, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Bfn7scDq, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_cn7xYak3, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_nNmz4r3m, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_rrdX9lu4, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_D5n6QwL7, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Si7YCTOd, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_j6XLy77r, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_5P3i24DQ, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_eDOZXxAF, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_obeV3vmO, VIf(Bf0));
    __hv_varwrite_f(&sVarf_dDRR30Fg, VIf(Bf8));
    __hv_line_f(&sLine_rFFazbjn, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_8b7OxT56, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_mwd7mao0, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_cS7BY53p, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_UG6HMhnf, VOf(Bf5));
    __hv_rpole_f(&sRPole_HVLtdsOl, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_STsFoYTL, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_BFaA2E5L, VOf(Bf6));
    __hv_rpole_f(&sRPole_WUmwWC6u, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_PiyZM6el, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_Eh06IYON, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_mpp4hzrt, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_w1qjihjn, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_KHCzTO32, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_TSgXNNc0, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ODVCT8sL, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_YDRdo39U, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_DTwTlh99, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_C09TBsEn, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_uweqV1Go, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_h3Led779, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_TPV4cke9, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_zeC4tKMb, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_omFF6cTp, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_i9fMCQ4B, VIf(Bf4));
    __hv_varwrite_f(&sVarf_1VzumjFX, VIf(Bf10));
    __hv_varwrite_f(&sVarf_tuHrmjp4, VIf(Bf2));
    __hv_varwrite_f(&sVarf_jEZfElsJ, VIf(Bf9));
    __hv_varwrite_f(&sVarf_7X6sbdCJ, VIf(Bf11));
    __hv_varread_f(&sVarf_YukM7lya, VOf(Bf11));
    __hv_varread_f(&sVarf_dDRR30Fg, VOf(Bf9));
    __hv_varread_f(&sVarf_1VzumjFX, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_tuHrmjp4, VOf(Bf2));
    __hv_varread_f(&sVarf_jEZfElsJ, VOf(Bf11));
    __hv_varread_f(&sVarf_7X6sbdCJ, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
